configurationtools.get_python_version_string
============================================

.. autofunction:: abjad.tools.configurationtools.get_python_version_string.get_python_version_string
   :noindex:
